@@ -6,22 +6,20 @@ import copy
 
 import singer
 from singer import metrics, metadata, Transformer, utils
-from singer.utils import strftime, strptime_to_utc
 
 from tap_ilevel.transform import transform_json, hash_data
 from tap_ilevel.streams import STREAMS
 import tap_ilevel.singer_operations as singer_ops
 import tap_ilevel.ilevel_api as ilevel
 
-from tap_ilevel.constants import ALL_RECORDS_STREAMS, INCREMENTAL_STREAMS, \
-    STANDARDIZED_PERIODIC_DATA_STREAMS, MAX_DATE_WINDOW, MAX_ID_CHUNK_SIZE
+from tap_ilevel.constants import ALL_RECORDS_STREAMS, INCREMENTAL_STREAMS, MAX_DATE_WINDOW
 
 LOGGER = singer.get_logger()
 
 
 def transform_datetime(this_dttm):
     with Transformer() as transformer:
-        new_dttm = transformer._transform_datetime(this_dttm)
+        new_dttm = transformer._transform_datetime(this_dttm) # pylint: disable=protected-access
     return new_dttm
 
 
@@ -45,8 +43,7 @@ def process_records(result_records,
     bookmark_field = req_state.bookmark_field
     last_date = req_state.last_date
 
-    LOGGER.info('{}: Preparing to publish {} records'.format(
-        stream_name, len(result_records)))
+    LOGGER.info('%s: Preparing to publish %s records', stream_name, len(result_records))
 
     stream = req_state.catalog.get_stream(stream_name)
     schema = stream.schema.to_dict()
@@ -57,7 +54,7 @@ def process_records(result_records,
         transformed_data = transform_json(result_records)
     except Exception as err:
         LOGGER.error(err)
-        LOGGER.error('result_records = {}'.format(result_records))
+        LOGGER.error('result_records = %s', result_records)
         raise err
 
     with metrics.record_counter(req_state.stream_name) as counter:
@@ -74,7 +71,7 @@ def process_records(result_records,
                         stream_metadata)
                 except Exception as err:
                     LOGGER.error(err)
-                    LOGGER.error('Error record: {}'.format(record))
+                    LOGGER.error('Error record: %s', record)
                     raise err
 
             # Reset max_bookmark_value to new value if higher
@@ -102,8 +99,7 @@ def process_records(result_records,
                     req_state.stream_name, transformed_record, utils.now())
                 counter.increment()
 
-        LOGGER.info('{}: Published {} records, max_bookmark_value: {}'.format(
-            stream_name, counter.value, max_bookmark_value))
+        LOGGER.info('%s: Published %s records, max_bookmark_value: %s', stream_name, counter.value, max_bookmark_value)
         return max_bookmark_value, counter.value
 
 
@@ -215,9 +211,9 @@ def __process_incremental_stream(req_state):
             cur_end_date = date_chunks[cur_date_range_index]
             cur_date_range_index = cur_date_range_index + 1
 
-        LOGGER.info('{}: Processing date range {} of {} total ({} - {})'.format(
-            req_state.stream_name, cur_date_range_index, cur_date_criteria_length, \
-                cur_start_date, cur_end_date))
+        LOGGER.info('%s: Processing date range %s of %s total (%s - %s)',
+                    req_state.stream_name, cur_date_range_index, cur_date_criteria_length,
+                    cur_start_date, cur_end_date)
 
         #Retrieve updated entities for given date range, and send for processing
         updated_object_id_sets = ilevel.get_updated_object_id_sets(
@@ -228,8 +224,8 @@ def __process_incremental_stream(req_state):
             cur_id_set_index = 0
             for id_set in updated_object_id_sets:
                 updated_record_count = 0
-                LOGGER.info('{}: Processing id set {} of {} total sets'.format(
-                    req_state.stream_name, cur_id_set_index + 1, len(updated_object_id_sets)))
+                LOGGER.info('%s: Processing id set %s of %s total sets',
+                            req_state.stream_name, cur_id_set_index + 1, len(updated_object_id_sets))
 
                 # Process updated object stream id set
                 max_bookmark_value_upd, updated_record_count = \
@@ -250,8 +246,8 @@ def __process_incremental_stream(req_state):
             cur_id_set_index = 0
             for id_set in deleted_object_id_sets:
                 deleted_record_count = 0
-                LOGGER.info('{}: Processing deleted id set {} of {} total sets'.format(
-                    req_state.stream_name, cur_id_set_index + 1, len(deleted_object_id_sets)))
+                LOGGER.info('%s: Processing deleted id set %s of %s total sets',
+                            req_state.stream_name, cur_id_set_index + 1, len(deleted_object_id_sets))
                 # Process deleted records
                 max_bookmark_value_del, deleted_record_count = \
                     __process_deleted_object_stream_id_set(
@@ -332,8 +328,8 @@ def __process_standardized_data_stream(req_state):
             cur_end_date = date_chunks[cur_date_range_index]
             cur_date_range_index = cur_date_range_index + 1
 
-        LOGGER.info('periodic_data_standardized, {} - {}, Date Range: {} of {}'.format(
-                cur_start_date, cur_end_date, cur_date_range_index, cur_date_criteria_length))
+        LOGGER.info('periodic_data_standardized, %s - %s, Date Range: %s of %s',
+                    cur_start_date, cur_end_date, cur_date_range_index, cur_date_criteria_length)
 
         #Get updated records based on date range
         updated_object_id_sets = ilevel.get_standardized_data_id_chunks(
@@ -341,8 +337,8 @@ def __process_standardized_data_stream(req_state):
         if len(updated_object_id_sets) == 0:
             continue
 
-        LOGGER.info('periodic_data_standardized, {} - {}, Updated Sets: {}'.format(
-                cur_start_date, cur_end_date, len(updated_object_id_sets)))
+        LOGGER.info('periodic_data_standardized, %s - %s, Updated Sets: %s',
+                    cur_start_date, cur_end_date, len(updated_object_id_sets))
 
         #Translate standardized ids to objects
         batch = 1
@@ -355,8 +351,8 @@ def __process_standardized_data_stream(req_state):
             if temp_max_bookmark_value_dttm > max_bookmark_value_dttm:
                 max_bookmark_value = temp_max_bookmark_value
 
-            LOGGER.info('periodic_data_standardized, {} - {}, Batch #{}, Requests: {}, Results: {}'.format(
-                cur_start_date, cur_end_date, batch, len(id_set), processed_record_count))
+            LOGGER.info('periodic_data_standardized, %s - %s, Batch #%s, Requests: %s, Results: %s',
+                        cur_start_date, cur_end_date, batch, len(id_set), processed_record_count)
             update_count = update_count + processed_record_count
             batch = batch + 1
 
@@ -375,49 +371,47 @@ def __process_standardized_data_stream(req_state):
     return update_count
 
 
-def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_code='USD'):
+def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_code='USD'): # pylint: disable=too-many-statements
     entity_types = ['assets'] # Currently: assets only (not funds)
     period_types = req_state.period_types.strip().replace(' ', '').split(',')
     batch_size = 10000
-    start_dttm = datetime.strptime(req_state.last_date, '%Y-%m-%d')
     end_dttm = req_state.end_date
     max_bookmark_value = req_state.last_date
-    
+
     # Init params_list and results
     i_get_params_list = req_state.client.factory.create('ArrayOfBaseRequestParameters')
     results = []
     req_id = 1
     batch = 1
     update_count = 0
-    
+
     # Base objects
     data_value_types = req_state.client.factory.create('DataValueTypes')
-    
+
     # scenario_id for scenario_name
     scenarios = req_state.client.service.GetScenarios()
     scenario = [i for i in scenarios.NamedEntity if i.Name == scenario_name][0]
     scenario_id = scenario.Id
-    
+
     # current_date
     date_types = req_state.client.factory.create('DateTypes')
     current_date = req_state.client.factory.create('Date')
     current_date.Type = date_types.Current
-    
+
     # latest_date
     latest_date = req_state.client.factory.create('Date')
     latest_date.Type = date_types.Latest
-    
+
     # Get all calc data items
     data_item_search_criteria = req_state.client.factory.create('DataItemsSearchCriteria')
     data_item_search_criteria.GetGlobalDataItemsOnly = True # Global Data Items ONLY
     data_items = req_state.client.service.GetDataItems(data_item_search_criteria)
     calc_data_items = [i for i in data_items.DataItemObjectEx if i.FormulaTypeIDsString] # TESTING (add): and 'Gross Margin' in i.Name
     calc_data_items_len = len(calc_data_items)
-    last_calc_data_item = calc_data_items[-1]
-    
+
     # entity_type loop
-    for entity_type in entity_types: # funds, assets
-        LOGGER.info('entity_type = {}'.format(entity_type)) # COMMENT OUT
+    for entity_type in entity_types: # funds, assets pylint: disable=too-many-nested-blocks
+        LOGGER.info('entity_type = %s', entity_type) # COMMENT OUT
         # entity_ids for funds_or_assets
         if entity_type == 'funds':
             entities = req_state.client.service.GetFunds()
@@ -428,13 +422,13 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
             entity_objs = entities.Asset
             # entity_objs = [i for i in entity_objs if 'Guild Education' in i.Name] # TESTING: COMMENT OUT
         entity_objs_len = len(entity_objs)
-    
+
         # calc_data_items loop
         cdi = 1
         for data_item in calc_data_items:
             data_item_id = data_item.Id
             data_item_name = data_item.Name
-            LOGGER.info('data_item_name = {} ({})'.format(data_item_name, data_item_id)) # COMMENT OUT
+            LOGGER.info('data_item_name = %s (%s)', data_item_name, data_item_id) # COMMENT OUT
 
             # data_value_type for data_item
             data_value_type_id = data_item.DataValueType
@@ -445,10 +439,11 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
             for entity in entity_objs:
                 entity_dict = ilevel.sobject_to_dict(entity)
                 entity_id = entity_dict.get('Id')
-                entity_name = entity_dict.get('Name')
                 # LOGGER.info('entity = {} ({})'.format(entity_name, entity_id)) # COMMENT OUT
                 entity_initial_dttm = datetime.strptime(entity_dict.get('InitialPeriod')[:10], '%Y-%m-%d')
+                start_dttm = datetime.strptime(req_state.last_date, '%Y-%m-%d')
                 max_dttm = [start_dttm, entity_initial_dttm]
+                # Choose the earliest date for which there is data for an entity
                 start_dttm = max(i for i in max_dttm if i is not None)
 
                 # LOGGER.info('periodic_data_calculated: {}, {}: {} ({})'.format(
@@ -491,7 +486,7 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
                             end_of_batches = True
                             LOGGER.info('xxx END OF BATCHES xxx')
                         if (req_id % batch_size == 0) or end_of_batches:
-                            LOGGER.info('xxx BATCH: {} xxx'.format(batch))
+                            LOGGER.info('xxx BATCH: %s xxx', batch)
                             i_get_count = len(i_get_params_list)
                             i_get_request = req_state.client.factory.create('DataServiceRequest')
                             i_get_request.IncludeStandardizedDataInfo = True
@@ -513,8 +508,8 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
                             try:
                                 periodic_data_records = data_values.DataValue
                             except Exception as err:
-                                LOGGER.error('{}'.format(err))
-                                LOGGER.error('data_values dict = {}'.format(ilevel.sobject_to_dict(data_values)))
+                                LOGGER.error('%s', err)
+                                LOGGER.error('data_values dict = %s', ilevel.sobject_to_dict(data_values))
                                 raise err
 
                             for periodic_data_record in periodic_data_records:
@@ -523,7 +518,7 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
 
                                 if "NoDataAvailable" in periodic_data_record:
                                     continue
-                                
+
                                 periodic_data_record_dict = ilevel.sobject_to_dict(periodic_data_record)
                                 # LOGGER.info('period_data_record_dict = {}'.format(periodic_data_record_dict)) # COMMENT OUT
 
@@ -534,10 +529,11 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
                                     value = transformed_record.get('value')
                                     value_string = str(value)
                                     if type(value) in (int, float):
-                                            value_numeric = float(value)
+                                        value_numeric = float(value)
                                     else:
                                         value_numeric = None
                                     if value == 'No Data Available':
+                                        LOGGER.info('No Data Available, skipping record')
                                         continue
                                     sd_parameters = transformed_record.get('sd_parameters', {})
                                     excel_formula = transformed_record.get('excel_formula')
@@ -553,7 +549,7 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
                                     exchange_rate_type = sd_parameters.get('exchange_rate', {}).get('type')
                                     request_id = sd_parameters.get('request_identifier')
                                     standardized_data_id = sd_parameters.get('standardized_data_id')
-                                    
+
                                     dimensions = {
                                         'data_item_id': data_item_id,
                                         'entity_id': entity_id,
@@ -587,7 +583,7 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
                                         'value_string': value_string,
                                         'value_numeric': value_numeric
                                     }
-                                    
+
                                     results.append(new_record)
                                 # end for rec in period_data_records
 
@@ -599,7 +595,7 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
                                 max_bookmark_value=max_bookmark_value)
 
                             update_count = update_count + process_record_count
-                            
+
                             # Init new params_list and results
                             i_get_params_list = req_state.client.factory.create('ArrayOfBaseRequestParameters')
                             results = []
@@ -615,7 +611,7 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
 
                 ent = ent + 1
                 # end entity_id loop
-                
+
             cdi = cdi + 1
             # end calc_data_items loop
 
@@ -637,13 +633,13 @@ def __sync_endpoint(req_state):
 
     with metrics.job_timer('endpoint_duration'):
 
-        LOGGER.info('{}: STARTED Syncing stream'.format(req_state.stream_name))
+        LOGGER.info('%s: STARTED Syncing stream', req_state.stream_name)
         singer_ops.update_currently_syncing(req_state.state, req_state.stream_name)
 
         # Publish schema to singer
         singer_ops.write_schema(req_state.catalog, req_state.stream_name)
-        LOGGER.info('{}: Processing date window, {} to {}'.format(
-            req_state.stream_name, req_state.last_date, req_state.end_date))
+        LOGGER.info('%s: Processing date window, %s to %s',
+                    req_state.stream_name, req_state.last_date, req_state.end_date)
 
         if req_state.stream_name in ALL_RECORDS_STREAMS:
             endpoint_total = __process_all_records_data_stream(req_state)
@@ -659,8 +655,8 @@ def __sync_endpoint(req_state):
             endpoint_total = __process_incremental_stream(req_state)
 
         singer_ops.update_currently_syncing(req_state.state, None)
-        LOGGER.info('{}: FINISHED Syncing Stream, total_records: {}'.format(
-            req_state.stream_name, endpoint_total))
+        LOGGER.info('%s: FINISHED Syncing Stream, total_records: %s',
+                    req_state.stream_name, endpoint_total)
 
     LOGGER.info('sync.py: sync complete')
 
@@ -675,14 +671,14 @@ def sync(client, config, catalog, state):
     # Get selected_streams from catalog, based on state last_stream
     #   last_stream = Previous currently synced stream, if the load was interrupted
     last_stream = singer.get_currently_syncing(state)
-    LOGGER.info('last/currently syncing stream: {}'.format(last_stream))
+    LOGGER.info('last/currently syncing stream: %s', last_stream)
     selected_streams = []
     selected_streams_by_name = {}
     for stream in catalog.get_selected_streams(state):
         selected_streams.append(stream.stream)
         selected_streams_by_name[stream.stream] = stream
 
-    LOGGER.info('selected_streams: {}'.format(selected_streams))
+    LOGGER.info('selected_streams: %s', selected_streams)
 
     if not selected_streams or selected_streams == []:
         return
@@ -690,7 +686,7 @@ def sync(client, config, catalog, state):
     # Loop through endpoints in selected_streams
     for stream_name, endpoint_config in STREAMS.items():
         if stream_name in selected_streams:
-            LOGGER.info('START Syncing: {}'.format(stream_name))
+            LOGGER.info('START Syncing: %s', stream_name)
             stream = selected_streams_by_name[stream_name]
 
             bookmark_field = next(iter(endpoint_config.get('replication_keys', [])), None)
@@ -717,8 +713,8 @@ def sync(client, config, catalog, state):
             # Main sync routine
             total_records = __sync_endpoint(req_state)
 
-            LOGGER.info('FINISHED Syncing: {}, total_records: {}'.format(
-                stream_name,
-                total_records))
+            LOGGER.info('FINISHED Syncing: %s, total_records: %s',
+                        stream_name,
+                        total_records)
 
     LOGGER.info('sync.py: sync complete')
